Project Authors
===============

## Developers:

* Paleari, Fulvio, Istituto Nanoscienze (Italy)
* Molina-Sánchez, Alejandro, Universitat de València (Spain)
* Reho, Riccardo, Utrecht University (Netherlands)
* Bonacci, Miki, Paul Scherrer Institute (Switzerland)
* Castelo, José, Universitat de València (Spain)
* Cervantes-Villanueva, Jorge, Universitat de València (Spain)
* Pionteck, Mike, University of Giessen (Germany)
* Silvetti, Martino, University of Modena and Reggio Emilia (Italy)
* Attaccalite, Claudio, CNRS/Aix-Marseille University (France)
* Pereira Coutada Miranda, Henrique, VASP Software (Austria)
* Myrta Grüning, Queen's University, Belfast (UK)

## All other contributors and their affiliations:

* Michele Re Fiorentin
* Matteo Zanfrognini
* Alexandre Morlet
* Davide Romanin
* Daniel Murphy
* Yuncheng Mao
* Marco D'Alessandro
* Daniel Santos Stone
* Ignacio Alliati 
* Muralidhar Nalabothula
* Anna Romani
